"""A module contataining constants for ComractRenderer class

Thic type of layout renders a single exercise to a single slide list"""



TITLE_POSITION=(0.5,0.5)
TITLE_SIZE=(33,1)
TITLE_BACKGROUND=(46,117,182)
TITLE_FOREGROUND=(255,255,255)

SCHEME_POSITION=(12.0,2.0)
SCHEME_HEIGHT=8.5 # not used atm
SCHEME_WIDTH=12.5

LEFT_TABLE_POSITION=(0.5,2.0)
LEFT_TABLE_WIDTH=10.5

RIGHT_TABLE_POSITION=(12.0,10.5)
RIGHT_TABLE_WIDTH=21.5

LINKS_TITLE_POSITION=(0.5,13.5)
LINKS_AREA=(2.5,13.5)
LINKS_IMAGE_SIZE=(1,1)
LINKS_VIDEO_ICON_FILENAME='movie_google_icon.svg'
LINKS_ANIMATION_ICON_FILENAME='animation_google_icon.svg'
